@@ -8,12 +8,18 @@ import shutil
 import docker
 from uuid import uuid4
 from docker.types import Mount
+from docker.errors import DockerException
 
 # ################ #
 # GLOBAL VARIABLES #
 # ################ #
 
-client = docker.from_env()
+try:
+    client = docker.from_env()
+except DockerException:
+    print("ERROR: Docker service is not running", file=sys.stderr)
+    print("       Please, start docker service and try again", file=sys.stderr)
+    exit(1)
 api_client = docker.APIClient(base_url='unix://var/run/docker.sock')
 master_name = 'pycompss-master'
 worker_name = 'pycompss-worker'
@@ -43,7 +49,7 @@ elif len(client.containers.list(filters={'name': master_name})) > 0:
     image_name = master.image.attrs['RepoTags'][0]
 else:
     # Otherwise, fallback to default COMPSs image
-    image_name = 'compss/compss:2.8'  # Update when releasing new version
+    image_name = 'compss/compss:2.9'  # Update when releasing new version
 
 
 # ############# #
@@ -121,7 +127,7 @@ def exec_in_daemon(cmd: str):
     """
     print("Executing cmd: %s" % cmd)
     if not _is_running(master_name):
-        _start_daemon()
+        start_daemon()
 
     master = _get_master()
     _, output = master.exec_run(cmd, workdir=default_workdir, stream=True)
@@ -136,7 +142,7 @@ def start_monitoring():
     """
     print("Starting Monitor")
     if not _is_running(master_name):
-        _start_daemon()
+        start_daemon()
 
     cmd = "/etc/init.d/compss-monitor start"
     master = _get_master()
@@ -350,6 +356,7 @@ def _get_mounts(user_working_dir: str):
     user_dir = Mount(target=target_dir,
                      source=user_working_dir,
                      type='bind')
+    # WARNING: mounting .COMPSs makes it fail
     # compss_dir = os.environ['HOME'] + '/.COMPSs'
     # os.makedirs(compss_dir, exist_ok=True)
     #
@@ -374,17 +381,20 @@ def _generate_project_cfg(ips: list = (), cpus: int = 4,
     # ./generate_project.sh project.xml "172.17.0.3:4:/opt/COMPSs:/tmp"
     master = _get_master()
     proj_cmd = '/opt/COMPSs/Runtime/scripts/system/xmls/generate_project.sh'
-    proj_arg = ' '.join(
+    master_ip = '127.0.0.1'
+    workers_ip = ips
+    proj_master = ":".join((master_ip, "0", install_dir, worker_dir))
+    proj_workers = ' '.join(
         ["%s:%s:%s:%s" % (ip, cpus, install_dir, worker_dir) for ip in
-         ips])
-    cmd = "%s /project.xml '%s'" % (proj_cmd, proj_arg)
+        workers_ip])
+    cmd = "%s /project.xml '%s' '%s'" % (proj_cmd, proj_master, proj_workers)
     exit_code, output = master.exec_run(cmd=cmd)
     if exit_code != 0:
         print("Exit code: %s" % exit_code)
         for line in [l for l in output.decode().split('\n')]:
             print(line)
         sys.exit(exit_code)
-    return proj_arg
+    return proj_workers
 
 
 def _generate_resources_cfg(ips: list = (), cpus: int = 4):
